var ChartSettings, LineChart, changeGraph, chartsNotInitialized, diffDays, getApiKey, getRequests, make2DArray, makeCharts, makeDailyChart, makeWeeklyChart, setHeaders,
  bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };

ChartSettings = (function() {
  function ChartSettings() {
    this.margin = {
      top: 20,
      right: 20,
      bottom: 30,
      left: 40
    };
    this.width = 640 - this.margin.left - this.margin.right;
    this.height = 500 - this.margin.top - this.margin.bottom;
    this.title_height = 16;
    this.color = d3.scale.ordinal().range(['rgb(241,238,246)', 'rgb(208,209,230)', 'rgb(166,189,219)', 'rgb(116,169,207)', 'rgb(54,144,192)', 'rgb(5,112,176)', 'rgb(3,78,123)'].reverse());
  }

  ChartSettings.prototype.svgWidth = function() {
    return this.width + this.margin.left + this.margin.right;
  };

  ChartSettings.prototype.svgHeight = function() {
    return this.height + this.margin.top + this.margin.bottom;
  };

  ChartSettings.prototype.svgTransformValue = function() {
    return "translate(" + this.margin.left + ", " + this.margin.top + ")";
  };

  return ChartSettings;

})();

LineChart = (function() {
  function LineChart(chart_data, chart_title, max_y_val) {
    this.chart_data = chart_data;
    this.chart_title = chart_title;
    this.setChartAxes = bind(this.setChartAxes, this);
    this.chart_settings = new ChartSettings();
    this.max_y_val = max_y_val || 3600;
    this.setChartAxes();
  }

  LineChart.prototype.line_function = function() {
    return d3.svg.line().x((function(_this) {
      return function(d, i) {
        return _this.x(i);
      };
    })(this)).y((function(_this) {
      return function(d) {
        return _this.y(d);
      };
    })(this));
  };

  LineChart.prototype.setChartAxes = function() {
    var max;
    max = d3.max(this.chart_data);
    if (this.chart_title === "Weekly Requests") {
      max = d3.max([this.max_y_val + (this.max_y_val * 0.1), d3.max(this.chart_data)]);
    }
    this.x = d3.scale.linear().domain([0, this.chart_data.length - 1]).range([0, this.chart_settings.width]);
    this.y = d3.scale.linear().domain([0, max]).range([this.chart_settings.height, this.chart_settings.title_height]);
    this.x_axis = d3.svg.axis().scale(this.x).orient('bottom').tickFormat(d3.format('d')).tickSubdivide(0);
    return this.y_axis = d3.svg.axis().scale(this.y).orient('left').tickFormat(d3.format('d')).tickSubdivide(0);
  };

  LineChart.prototype.render = function(selector) {
    var i, svg, throttle_line;
    svg = d3.select(selector).append("svg").attr("width", this.chart_settings.svgWidth()).attr("height", this.chart_settings.svgHeight()).append('g').attr('transform', this.chart_settings.svgTransformValue());
    svg.append('g').attr('class', 'x-axis axis').attr('transform', "translate(0, " + this.chart_settings.height + ")").call(this.x_axis);
    svg.append('g').attr('class', 'y-axis axis').call(this.y_axis).append('text').attr('transform', 'rotate(-90)').attr('y', 6).attr('dy', '.7em').style('text-anchor', 'end').text('Request Count');
    svg.append('path').attr('d', this.line_function()(this.chart_data)).attr('stroke', 'steelblue').attr('stroke-width', 2).attr('fill', 'none');
    if (this.chart_title === "Weekly Requests") {
      throttle_line = (function() {
        var j, ref, results;
        results = [];
        for (i = j = 1, ref = this.chart_data.length; 1 <= ref ? j <= ref : j >= ref; i = 1 <= ref ? ++j : --j) {
          results.push(this.max_y_val);
        }
        return results;
      }).call(this);
      return svg.append('path').attr('d', this.line_function()(throttle_line)).attr('stroke', 'steelblue').style('stroke-dasharray', '3, 3').attr('stroke-width', 2).attr('fill', 'none');
    }
  };

  return LineChart;

})();

getApiKey = function() {
  return $('meta[name=api_key]')[0].content;
};

changeGraph = function(show) {
  if (show === 'daily') {
    $('#weekly-chart').addClass('hidden');
    $('#daily-chart').removeClass('hidden');
  }
  if (show === 'weekly') {
    $('#weekly-chart').removeClass('hidden');
    return $('#daily-chart').addClass('hidden');
  }
};

setHeaders = function(xhr) {
  return xhr.setRequestHeader('Authorization', "Bearer " + (getApiKey()));
};

chartsNotInitialized = true;

makeCharts = function(data) {
  chartsNotInitialized = false;
  makeDailyChart(data.daily_reqs);
  return makeWeeklyChart(data.weekly_reqs);
};

make2DArray = function(length) {
  var j, num, ref, results;
  results = [];
  for (num = j = 1, ref = length; 1 <= ref ? j <= ref : j >= ref; num = 1 <= ref ? ++j : --j) {
    results.push(0);
  }
  return results;
};

diffDays = function(before, now) {
  var oneDay;
  oneDay = 24 * 60 * 60 * 1000;
  return Math.round(Math.abs((now.getTime() - new Date(before).getTime()) / oneDay));
};

getRequests = function() {
  var options;
  options = {
    beforeSend: setHeaders,
    url: '/dashboard/requests',
    method: 'GET'
  };
  return $.ajax(options).done(function(data) {
    $('#requests-made').html(data.data.daily_reqs.length);
    if (chartsNotInitialized) {
      return makeCharts(data.data);
    }
  }).fail(function(data) {
    return console.log(data);
  });
};

makeDailyChart = function(requests) {
  var d, dailyChart, j, len, lineFunction, req, todaysHours;
  todaysHours = make2DArray(24);
  for (j = 0, len = requests.length; j < len; j++) {
    req = requests[j];
    d = new Date(req.time_requested);
    todaysHours[d.getUTCHours()] = todaysHours[d.getUTCHours()] + 1;
  }
  lineFunction = d3.svg.line().x(function(d, i) {
    return x(i);
  }).y(function(d, i) {
    return y(d);
  }).interpolate("linear");
  dailyChart = new LineChart(todaysHours, 'Daily Requests');
  return dailyChart.render('#daily-chart');
};

makeWeeklyChart = function(requests) {
  var idx, j, len, lineFunction, now, past7Days, req, weeklyChart;
  past7Days = make2DArray(7);
  now = new Date;
  for (j = 0, len = requests.length; j < len; j++) {
    req = requests[j];
    idx = diffDays(req.time_requested, now);
    if (idx < 7) {
      past7Days[idx] = past7Days[idx] + 1;
    }
  }
  lineFunction = d3.svg.line().x(function(d, i) {
    return x(i);
  }).y(function(d, i) {
    return y(d);
  }).interpolate("linear");
  weeklyChart = new LineChart(past7Days.reverse(), 'Weekly Requests', 3600 * Number($('meta[name=num_users]')[0].content));
  return weeklyChart.render('#weekly-chart');
};

$(function() {
  getRequests();
  $('#daily').on('click', function() {
    return changeGraph('daily');
  });
  return $('#weekly').on('click', function() {
    return changeGraph('weekly');
  });
});
